Atmo class
- Implementers
Constructors
- Atmo({Distance? altitude, Pressure? pressure, Temperature? temperature, double humidity = 0.0, Temperature? powderTemperature})
- Atmo.icao({Distance? altitude, Temperature? temperature, double humidity = 0.0})
-
factory
Properties
- altitude → Distance
-
no setter
- densityImperial → double
-
no setter
- densityMetric → double
-
no setter
- densityRatio → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- humidity ↔ double
-
getter/setter pair
- mach → Velocity
-
no setter
- powderTemp → Temperature
-
no setter
- pressure → Pressure
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature → Temperature
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDensityRatio(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- cLowestTempC → double
-
final
Static Methods
-
calculateAirDensity(
double tCelsius, double p_hpa, double humidityFraction) → double -
machF(
double fahrenheit) → double -
standardPressure(
Distance altitude) → Pressure -
standardTemperature(
Distance altitude) → Temperature