HitResult class

Constructors

HitResult(Shot shot, List<TrajectoryData> trajectory, {int filterFlags = 0, Exception? error})

Properties

error Exception?
final
filterFlags int
final
hashCode int
The hash code for this object.
no setterinherited
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shot Shot
final
trajectory List<TrajectoryData>
final
zeros List<TrajectoryData>
no setter

Methods

getAtDistance(Distance d) TrajectoryData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited