Vector class

Constructors

Vector(double x, double y, double z)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final
z → double
final

Methods

copy() → Vector
dot(Vector b) → double
mag() → double
norm() → Vector
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(double a) → Vector
operator +(Vector b) → Vector
operator -(Vector b) → Vector
operator ==(Object other) → bool
The equality operator.
inherited
operator unary-() → Vector

Static Methods

sum(Iterable<Vector> vectors) → Vector

Constants

zero → const Vector