Wind class

Constructors

Wind({Velocity? velocity, Angular? directionFrom, Distance? untilDistance, double? customMaxDistanceFeet})

Properties

directionFrom Angular
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
untilDistance Distance
final
velocity Velocity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

maxDistanceFeet double
getter/setter pair