Angular class

Inheritance

Constructors

Angular(double value, Unit unit)
Angular.cmPer100m(double value)
factory
Angular.degree(double value)
factory
Angular.inPer100Yd(double value)
factory
Angular.mil(double value)
factory
Angular.moa(double value)
factory
Angular.mRad(double value)
factory
Angular.oClock(double value)
factory
Angular.radian(double value)
factory
Angular.thousandth(double value)
factory

Properties

conversionFactors Map<Unit, double>
no setteroverride
debugDetails String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
raw double
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
units Unit
no setterinherited
value double
no setterinherited

Methods

in_(Unit unit) double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to(Unit unit) Angular
inherited
toDouble() double
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

accepts(Unit u) bool

Constants

rawUnit → const Unit