Dimension<T extends Dimension<T>> class abstract

Implementers

Constructors

Dimension(double value, Unit _units)

Properties

conversionFactors Map<Unit, double>
no setter
debugDetails String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
raw double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
units Unit
no setter
value double
no setter

Methods

in_(Unit unit) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to(Unit unit) → T
toDouble() double
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

auto(Object value, Unit units) Dimension