Velocity class

Inheritance
Available extensions

Constructors

Velocity(double value, Unit unit)
Velocity.fps(double value)
factory
Velocity.kmh(double value)
factory
Velocity.kt(double value)
factory
Velocity.mph(double value)
factory
Velocity.mps(double value)
factory

Properties

conversionFactors Map<Unit, double>
no setteroverride
debugDetails String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
raw double
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
units Unit
no setterinherited
value double
no setterinherited

Methods

in_(Unit unit) double
inherited
inMach([Atmo? atmo]) double

Available on Velocity, provided by the VelocityMachExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to(Unit unit) Velocity
inherited
toDouble() double
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

accepts(Unit u) bool

Constants

rawUnit → const Unit