TrajectoryData class
Constructors
- TrajectoryData({required double time, required Distance distance, required Velocity velocity, required double mach, required Distance height, required Distance slantHeight, required Angular dropAngle, required Distance windage, required Angular windageAngle, required Distance slantDistance, required Angular angle, required double densityRatio, required double drag, required Energy energy, required Weight ogw, required int flag})
Properties
- angle → Angular
-
final
- densityRatio → double
-
final
- distance → Distance
-
final
- drag → double
-
final
- dropAngle → Angular
-
final
- energy → Energy
-
final
- flag → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → Distance
-
final
- mach → double
-
final
- ogw → Weight
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slantDistance → Distance
-
final
- slantHeight → Distance
-
final
- time → double
-
final
- velocity → Velocity
-
final
- windage → Distance
-
final
- windageAngle → Angular
-
final
Methods
-
formatted(
) → List< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited